#ifndef NT2_INCLUDE_FUNCTIONS_OFSAMEWIDTH_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_OFSAMEWIDTH_HPP_INCLUDED

#include <nt2/predicates/include/functions/ofsamewidth.hpp>

#endif
